==> apeman-ui-contrib-angular-locating-1.2.3.tgz: package/README.md <==
apeman-ui-contrib-angular-locating
======

[![Build Status][my_travis_badge_url]][my_travis_url]
[![Code Climate][my_codeclimate_badge_url]][my_codeclimate_url]
[![Code Coverage][my_codeclimate_coverage_badge_url]][my_codeclimate_url]
[![npm version][my_npm_budge_url]][my_npm_url]

apeman ui module for angular to work with location.


Installation
-------

Install module via [npm][npm_url]

```bash
$ npm install apeman-ui-contrib-angular-locating --save-dev
```

Generating UI Files.
-------------------

1. Define an app at `$ui` property in your Apemanfile.
2. Set "apeman-ui-contrib-angular-locating" to `$invoke` property.

```javascript
/**
 * This is example Apemanfile to use "apeman-ui-contrib-angular-locating".
 */

"use strict";

module.exports = {
    $pkg: {/*...*/},
    $ui: {
        // Define your own ui.
        "my-ui-01": {
            // UI generation config for each path.
            "assets/public": {
                "$invoke": "apeman-ui-contrib-angular-locating",
                "$args": [
                ],
                "$options": {
                }
            }
        }
    }
};
```

Then, generate ui assets via [apeman app ui][apeman_ui_doc_url].

```bash
# Generate ui from CLI.
$ apeman ui "my-ui-01"
```

Using UI Files
--------------

```javascript
/**
 * This is example to use "apeman-ui-contrib-angular-locating".
 */

(function () {
    "use strict";

    angular
        .module('my-example-module', [
            'apeman-ui-contrib-angular-locating'
        ])
        .controller('ExampleCtrl', function (apLocationSearch) {
            // Work with hash bang params.

            apLocationSearch.set({
                foo: 'bar'
            });
            apLocationSearch.set('foo', 'bar');

            var foo = apLocationSearch.get('foo');

            // Get and delete 'foo'.
            var foo2 = apLocationSearch.consume('foo');

            apLocationSearch.delete('baz');
        });

})();
```

Options
-------

Values which can be passed to `$options` property.

| Name | Type | Description |
| ---- | ---- | ----------- |


Documents
-------

+ [apLocationSearch](assets/docs/apeman-ui-contrib-angular-locating/service/apLocationSearch.md)


License
-------

This software is released under the [MIT License][my_license_url].


Links
-------

+ [apeman][apeman_url]


[npm_url]: https://www.npmjs.com/
[apeman_url]: https://github.com/apeman-repo/apeman
[apeman_ui_doc_url]: https://github.com/apeman-repo/apeman#ui
[my_repo_url]: https://github.com/apeman-repo/apeman-ui-contrib-angular-locating
[my_travis_url]: http://travis-ci.org/apeman-repo/apeman-ui-contrib-angular-locating
[my_travis_badge_url]: http://img.shields.io/travis/apeman-repo/apeman-ui-contrib-angular-locating.svg?style=flat
[my_license_url]: https://github.com/apeman-repo/apeman-ui-contrib-angular-locating/blob/master/LICENSE
[my_codeclimate_url]: http://codeclimate.com/github/apeman-repo/apeman-ui-contrib-angular-locating
[my_codeclimate_badge_url]: http://img.shields.io/codeclimate/github/apeman-repo/apeman-ui-contrib-angular-locating.svg?style=flat
[my_codeclimate_coverage_badge_url]: http://img.shields.io/codeclimate/coverage/github/apeman-repo/apeman-ui-contrib-angular-locating.svg?style=flat
[my_npm_url]: http://www.npmjs.org/package/apeman-ui-contrib-angular-locating
[my_npm_budge_url]: http://img.shields.io/npm/v/apeman-ui-contrib-angular-locating.svg?style=flat
[coz_url]: http://okunishinishi.github.io/node-coz/apiguide

==> apeman-ui-contrib-angular-locating-1.2.4.tgz: package/README.md <==
apeman-ui-contrib-angular-locating
======

[![Build Status][my_travis_badge_url]][my_travis_url]
[![Code Climate][my_codeclimate_badge_url]][my_codeclimate_url]
[![Code Coverage][my_codeclimate_coverage_badge_url]][my_codeclimate_url]
[![npm version][my_npm_budge_url]][my_npm_url]
[![bower version][my_bower_badge_url]][my_repo_url]

apeman ui module for angular to work with location.


Installation
-------

Install module via [npm][npm_url]

```bash
$ npm install apeman-ui-contrib-angular-locating --save
```

Generating UI Files.
-------------------

1. Define `$ui` property in your Apemanfile.
2. Set "apeman-ui-contrib-angular-locating" to `$invoke` property.

```javascript
/**
 * This is example Apemanfile to use "apeman-ui-contrib-angular-locating".
 */

"use strict";

module.exports = {
    $pkg: {/*...*/},
    $ui: {
        // Define your own ui.
        "my-ui-01": {
            // UI generation config for each path.
            "assets/public/my_ui_components": [
                    require("apeman-ui-contrib-angular-locating)({

                    })
            ]
        }
    }
};
```

Then, generate ui assets via [apeman ui][apeman_ui_doc_url].

```bash
# Generate ui from CLI.
$ apeman ui "my-ui-01"
```

Options
-------

Values which can be passed to `$options` property.

| Name | Type | Description |
| ---- | ---- | ----------- |


Using UI Files
--------------

```javascript
/**
 * This is example to use "apeman-ui-contrib-angular-locating".
 */

(function () {
    "use strict";

    angular
        .module('my-example-module', [
            'apeman-ui-contrib-angular-locating'
        ])
        .controller('ExampleCtrl', function (apLocationSearch) {
            // Work with hash bang params.

            apLocationSearch.set({
                foo: 'bar'
            });
            apLocationSearch.set('foo', 'bar');

            var foo = apLocationSearch.get('foo');

            // Get and delete 'foo'.
            var foo2 = apLocationSearch.consume('foo');

            apLocationSearch.delete('baz');
        });

})();
```

Documents
-------

+ [apLocationSearch](assets/docs/apeman-ui-contrib-angular-locating/service/apLocationSearch.md)


License
-------

This software is released under the [MIT License][my_license_url].


Links
-------

+ [apeman][apeman_url]


[npm_url]: https://www.npmjs.com/
[apeman_url]: https://github.com/apeman-repo/apeman
[apeman_ui_doc_url]: https://github.com/apeman-repo/apeman#ui
[my_repo_url]: https://github.com/apeman-repo/apeman-ui-contrib-angular-locating
[my_travis_url]: http://travis-ci.org/apeman-repo/apeman-ui-contrib-angular-locating
[my_bower_badge_url]: https://img.shields.io/bower/v/apeman-ui-contrib-angular-locating.svg?style=flat
[my_travis_badge_url]: http://img.shields.io/travis/apeman-repo/apeman-ui-contrib-angular-locating.svg?style=flat
[my_license_url]: https://github.com/apeman-repo/apeman-ui-contrib-angular-locating/blob/master/LICENSE
[my_codeclimate_url]: http://codeclimate.com/github/apeman-repo/apeman-ui-contrib-angular-locating
[my_codeclimate_badge_url]: http://img.shields.io/codeclimate/github/apeman-repo/apeman-ui-contrib-angular-locating.svg?style=flat
[my_codeclimate_coverage_badge_url]: http://img.shields.io/codeclimate/coverage/github/apeman-repo/apeman-ui-contrib-angular-locating.svg?style=flat
[my_npm_url]: http://www.npmjs.org/package/apeman-ui-contrib-angular-locating
[my_npm_budge_url]: http://img.shields.io/npm/v/apeman-ui-contrib-angular-locating.svg?style=flat
[coz_url]: http://okunishinishi.github.io/node-coz/apiguide
